==> search_365-7.x-1.0-alpha1.tar.gz: search_365/src/SearchClient.php <==
<?php

namespace Drupal\search_365;

use Drupal\search_365\SearchResults\ResultSet;
use Drupal\search_365\SearchResults\SearchQuery;
use GuzzleHttp\ClientInterface;
use GuzzleHttp\Exception\GuzzleException;
use Symfony\Component\Serializer\SerializerInterface;

/**
 * Class SearchClient.
 *
 * @package Drupal\search_365\Service
 */
class SearchClient implements SearchClientInterface {

  /**
   * The base URL.
   *
   * @var string
   */
  protected $baseUrl;

  /**
   * The collection.
   *
   * @var string
   */
  protected $collection;

  /**
   * HTTP Client.
   *
   * @var \GuzzleHttp\ClientInterface
   */
  protected $httpClient;

  /**
   * The result set serializer.
   *
   * @var \Symfony\Component\Serializer\SerializerInterface
   */
  protected $serializer;

  /**
   * SearchClient constructor.
   *
   * @param $baseUrl
   *   The base URL.
   * @param $collection
   *   The collection.
   * @param \GuzzleHttp\ClientInterface $httpClient
   *   HTTP client.
   * @param \Symfony\Component\Serializer\SerializerInterface $serializer
   *   The result set serializer.
   */
  public function __construct($baseUrl, $collection, ClientInterface $httpClient, SerializerInterface $serializer) {
    $this->baseUrl = $baseUrl;
    $this->collection = $collection;
    $this->httpClient = $httpClient;
    $this->serializer = $serializer;
  }

  /**
   * {@inheritdoc}
   */
  public function search(SearchQuery $query) {
    try {
      $response = $this->httpClient->request('GET', $this->baseUrl . '/search/' . $this->collection . '/sitesearch/' . $query->getQuery() . '/' . $query->getPageNum() . '/' . $query->getSize());
      /** @var \Drupal\search_365\SearchResults\ResultSet $resultSet */
      $resultSet = $this->serializer->deserialize($response->getBody(), ResultSet::class, 'json');
      return $resultSet;
    }
    catch (GuzzleException $e) {
      throw new Search365Exception('Error querying search 365: ' . $e->getMessage(), $e->getCode(), $e);
    }
  }

}

==> search_365-8.x-1.0-alpha1.tar.gz: search_365/src/SearchClient.php <==
<?php

namespace Drupal\search_365;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\search_365\SearchResults\ResultSet;
use Drupal\search_365\SearchResults\SearchQuery;
use GuzzleHttp\ClientInterface;
use GuzzleHttp\Exception\GuzzleException;
use Symfony\Component\Serializer\SerializerInterface;

/**
 * Class SearchClient.
 *
 * @package Drupal\search_365\Service
 */
class SearchClient implements SearchClientInterface {

  /**
   * Config.
   *
   * @var \Drupal\Core\Config\Config
   */
  protected $config;

  /**
   * HTTP Client.
   *
   * @var \GuzzleHttp\ClientInterface
   */
  protected $httpClient;

  /**
   * The result set serializer.
   *
   * @var \Symfony\Component\Serializer\SerializerInterface
   */
  protected $serializer;

  /**
   * SearchClient constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   Config factory.
   * @param \GuzzleHttp\ClientInterface $httpClient
   *   HTTP client.
   * @param \Symfony\Component\Serializer\SerializerInterface $serializer
   *   The result set serializer.
   */
  public function __construct(ConfigFactoryInterface $configFactory, ClientInterface $httpClient, SerializerInterface $serializer) {
    $this->config = $configFactory->get('search_365.settings');
    $this->httpClient = $httpClient;
    $this->serializer = $serializer;
  }

  /**
   * {@inheritdoc}
   */
  public function search(SearchQuery $query) {
    // https://s365-uts-api.azurewebsites.net/search/utscollectionhere/sitesearch/course/1/20
    $baseurl = $this->config->get('connection_info.baseurl');
    $collection = $this->config->get('connection_info.collection');
    try {
      $response = $this->httpClient->request('GET', $baseurl . '/search/' . $collection . '/sitesearch/' . $query->getQuery() . '/' . $query->getPageNum() . '/' . $query->getSize());
      /** @var \Drupal\search_365\SearchResults\ResultSet $resultSet */
      $resultSet = $this->serializer->deserialize($response->getBody(), ResultSet::class, 'json');
      return $resultSet;
    }
    catch (GuzzleException $e) {
      throw new Search365Exception('Error querying search 365: ' . $e->getMessage(), $e->getCode(), $e);
    }
  }

}
